/********************************COPYRIGHT*************************************

    Copyright (C) 2002 - 2005 Brendt Wohlberg  <software@wohlberg.net>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this library; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

********************************COPYRIGHT*************************************/

/*
  This program extracts the scanner setting information embedded in
  TIFF files written by the NikonScan driver software for Nikon film
  scanners.

  Most recent modification: 5 April 2005
*/

#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <string.h>
#include "tiffdir.h"
#include "nsifd.h"

int main(int argc, char* argv[]) 
{ 
  char* filename = 0;
  int fixflag = 0;
  const char *usagestr = "usage: nsexif [-c] [-h] filename ...\n"
    "\t-c  Attempt to correct error in negative analog gains\n"
    "\t-h  Display usage information\n";
  NSSettings nss;
  int rval, nfiles, k;

  /* Parse command line */
  opterr = 0;
  while ((k = getopt (argc, argv, "ch")) != -1)
    switch (k) {
    case 'c': fixflag = 1;
      break;
    case 'h': fprintf(stderr, "%s", usagestr);
      exit(0);
    case '?': fprintf(stderr, "nsexif: unknown command line flag\n");
      exit(1);
    default:
      exit(1);
    }

  nfiles = argc - optind;
  if (nfiles <= 0) {
    fprintf(stderr,"nsexif: at least one image file must be specified\n");
    exit(1);
  }

  while (optind < argc) {
    filename = argv[optind];
    InitNSSettings(&nss);
    if ((rval = NSFileRead(filename, &nss, fixflag)) == 0) {
      if (nfiles > 1)
	printf("File:               %s\n", filename);
      PrintNSSettings(stdout, &nss);
      CleanNSSettings(&nss);
    } else
      exit(rval + 10);
    optind++;
    if (nfiles > 1 && optind < argc)
      fputc('\n', stdout);
  }

  exit(0);
}
